# Stubs for cachecontrol.controller (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

# from .cache import DictCache as DictCache
# from .serialize import Serializer as Serializer

logger = ...  # type: Any
URI = ...  # type: Any

def parse_uri(uri): ...

class CacheController:
    cache = ...  # type: Any
    cache_etags = ...  # type: Any
    serializer = ...  # type: Any
    def __init__(self, cache=None, cache_etags=True, serializer=None): ...
    @classmethod
    def cache_url(cls, uri): ...
    def parse_cache_control(self, headers): ...
    def cached_request(self, request): ...
    def conditional_headers(self, request): ...
    def cache_response(self, request, response, body=None): ...
    def update_cached_response(self, request, response): ...
