# Stubs for rdflib.plugins.parsers.notation3 (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

from rdflib.parser import Parser

class BadSyntax(SyntaxError):
    lines = ...  # type: Any
    def __init__(self, uri, lines, argstr, i, why): ...
    @property
    def message(self): ...
