from rdflib.namespace import DefinedNamespace as DefinedNamespace
from rdflib.namespace import Namespace as Namespace
from rdflib.term import URIRef as URIRef

class SDO(DefinedNamespace):
    ActiveActionStatus: URIRef
    CompletedActionStatus: URIRef
    FailedActionStatus: URIRef
    PotentialActionStatus: URIRef
    Researcher: URIRef
    GroupBoardingPolicy: URIRef
    ZoneBoardingPolicy: URIRef
    AudiobookFormat: URIRef
    EBook: URIRef
    Hardcover: URIRef
    Paperback: URIRef
    HearingImpairedSupported: URIRef
    TollFree: URIRef
    Friday: URIRef
    Monday: URIRef
    PublicHolidays: URIRef
    Saturday: URIRef
    Sunday: URIRef
    Thursday: URIRef
    Tuesday: URIRef
    Wednesday: URIRef
    OnSitePickup: URIRef
    CommentPermission: URIRef
    ReadPermission: URIRef
    WritePermission: URIRef
    AllWheelDriveConfiguration: URIRef
    FourWheelDriveConfiguration: URIRef
    FrontWheelDriveConfiguration: URIRef
    RearWheelDriveConfiguration: URIRef
    EventCancelled: URIRef
    EventMovedOnline: URIRef
    EventPostponed: URIRef
    EventRescheduled: URIRef
    EventScheduled: URIRef
    CoOp: URIRef
    MultiPlayer: URIRef
    SinglePlayer: URIRef
    OfflinePermanently: URIRef
    OfflineTemporarily: URIRef
    Online: URIRef
    OnlineFull: URIRef
    Female: URIRef
    Male: URIRef
    Discontinued: URIRef
    InStock: URIRef
    InStoreOnly: URIRef
    LimitedAvailability: URIRef
    OnlineOnly: URIRef
    OutOfStock: URIRef
    PreOrder: URIRef
    PreSale: URIRef
    SoldOut: URIRef
    ItemListOrderAscending: URIRef
    ItemListOrderDescending: URIRef
    ItemListUnordered: URIRef
    ParkingMap: URIRef
    SeatingMap: URIRef
    TransitMap: URIRef
    VenueMap: URIRef
    CompilationAlbum: URIRef
    DJMixAlbum: URIRef
    DemoAlbum: URIRef
    LiveAlbum: URIRef
    MixtapeAlbum: URIRef
    RemixAlbum: URIRef
    SoundtrackAlbum: URIRef
    SpokenWordAlbum: URIRef
    StudioAlbum: URIRef
    AlbumRelease: URIRef
    BroadcastRelease: URIRef
    EPRelease: URIRef
    SingleRelease: URIRef
    CDFormat: URIRef
    CassetteFormat: URIRef
    DVDFormat: URIRef
    DigitalAudioTapeFormat: URIRef
    DigitalFormat: URIRef
    LaserDiscFormat: URIRef
    VinylFormat: URIRef
    DamagedCondition: URIRef
    NewCondition: URIRef
    RefurbishedCondition: URIRef
    UsedCondition: URIRef
    OrderCancelled: URIRef
    OrderDelivered: URIRef
    OrderInTransit: URIRef
    OrderPaymentDue: URIRef
    OrderPickupAvailable: URIRef
    OrderProblem: URIRef
    OrderProcessing: URIRef
    OrderReturned: URIRef
    PaymentAutomaticallyApplied: URIRef
    PaymentComplete: URIRef
    PaymentDeclined: URIRef
    PaymentDue: URIRef
    PaymentPastDue: URIRef
    ReservationCancelled: URIRef
    ReservationConfirmed: URIRef
    ReservationHold: URIRef
    ReservationPending: URIRef
    DiabeticDiet: URIRef
    GlutenFreeDiet: URIRef
    HalalDiet: URIRef
    HinduDiet: URIRef
    KosherDiet: URIRef
    LowCalorieDiet: URIRef
    LowFatDiet: URIRef
    LowLactoseDiet: URIRef
    LowSaltDiet: URIRef
    VeganDiet: URIRef
    VegetarianDiet: URIRef
    RsvpResponseMaybe: URIRef
    RsvpResponseNo: URIRef
    RsvpResponseYes: URIRef
    LeftHandDriving: URIRef
    RightHandDriving: URIRef
    about: URIRef
    acceptedAnswer: URIRef
    acceptedOffer: URIRef
    acceptedPaymentMethod: URIRef
    acceptsReservations: URIRef
    accessCode: URIRef
    accessMode: URIRef
    accessModeSufficient: URIRef
    accessibilityAPI: URIRef
    accessibilityControl: URIRef
    accessibilityFeature: URIRef
    accessibilityHazard: URIRef
    accessibilitySummary: URIRef
    accountId: URIRef
    accountablePerson: URIRef
    acquiredFrom: URIRef
    actionAccessibilityRequirement: URIRef
    actionApplication: URIRef
    actionOption: URIRef
    actionPlatform: URIRef
    actionStatus: URIRef
    actor: URIRef
    actors: URIRef
    addOn: URIRef
    additionalName: URIRef
    additionalNumberOfGuests: URIRef
    additionalProperty: URIRef
    additionalType: URIRef
    address: URIRef
    addressCountry: URIRef
    addressLocality: URIRef
    addressRegion: URIRef
    advanceBookingRequirement: URIRef
    affiliation: URIRef
    afterMedia: URIRef
    agent: URIRef
    aggregateRating: URIRef
    aircraft: URIRef
    album: URIRef
    albumProductionType: URIRef
    albumRelease: URIRef
    albumReleaseType: URIRef
    albums: URIRef
    alignmentType: URIRef
    alternateName: URIRef
    alternativeHeadline: URIRef
    alumni: URIRef
    alumniOf: URIRef
    amenityFeature: URIRef
    amount: URIRef
    amountOfThisGood: URIRef
    annualPercentageRate: URIRef
    answerCount: URIRef
    application: URIRef
    applicationCategory: URIRef
    applicationSubCategory: URIRef
    applicationSuite: URIRef
    appliesToDeliveryMethod: URIRef
    appliesToPaymentMethod: URIRef
    area: URIRef
    areaServed: URIRef
    arrivalAirport: URIRef
    arrivalBusStop: URIRef
    arrivalGate: URIRef
    arrivalPlatform: URIRef
    arrivalStation: URIRef
    arrivalTerminal: URIRef
    arrivalTime: URIRef
    artEdition: URIRef
    artMedium: URIRef
    artform: URIRef
    articleBody: URIRef
    articleSection: URIRef
    artworkSurface: URIRef
    assembly: URIRef
    assemblyVersion: URIRef
    associatedArticle: URIRef
    associatedMedia: URIRef
    athlete: URIRef
    attendee: URIRef
    attendees: URIRef
    audience: URIRef
    audienceType: URIRef
    audio: URIRef
    authenticator: URIRef
    author: URIRef
    availability: URIRef
    availabilityEnds: URIRef
    availabilityStarts: URIRef
    availableAtOrFrom: URIRef
    availableChannel: URIRef
    availableDeliveryMethod: URIRef
    availableFrom: URIRef
    availableLanguage: URIRef
    availableOnDevice: URIRef
    availableThrough: URIRef
    award: URIRef
    awards: URIRef
    awayTeam: URIRef
    baseSalary: URIRef
    bccRecipient: URIRef
    bed: URIRef
    beforeMedia: URIRef
    benefits: URIRef
    bestRating: URIRef
    billingAddress: URIRef
    billingIncrement: URIRef
    billingPeriod: URIRef
    birthDate: URIRef
    birthPlace: URIRef
    bitrate: URIRef
    blogPost: URIRef
    blogPosts: URIRef
    boardingGroup: URIRef
    boardingPolicy: URIRef
    bookEdition: URIRef
    bookFormat: URIRef
    bookingAgent: URIRef
    bookingTime: URIRef
    borrower: URIRef
    box: URIRef
    branchCode: URIRef
    branchOf: URIRef
    brand: URIRef
    breadcrumb: URIRef
    broadcastAffiliateOf: URIRef
    broadcastChannelId: URIRef
    broadcastDisplayName: URIRef
    broadcastFrequency: URIRef
    broadcastFrequencyValue: URIRef
    broadcastOfEvent: URIRef
    broadcastServiceTier: URIRef
    broadcastTimezone: URIRef
    broadcaster: URIRef
    broker: URIRef
    browserRequirements: URIRef
    busName: URIRef
    busNumber: URIRef
    businessFunction: URIRef
    buyer: URIRef
    byArtist: URIRef
    calories: URIRef
    candidate: URIRef
    caption: URIRef
    carbohydrateContent: URIRef
    cargoVolume: URIRef
    carrier: URIRef
    carrierRequirements: URIRef
    catalog: URIRef
    catalogNumber: URIRef
    category: URIRef
    ccRecipient: URIRef
    character: URIRef
    characterAttribute: URIRef
    characterName: URIRef
    cheatCode: URIRef
    checkinTime: URIRef
    checkoutTime: URIRef
    childMaxAge: URIRef
    childMinAge: URIRef
    children: URIRef
    cholesterolContent: URIRef
    circle: URIRef
    citation: URIRef
    claimReviewed: URIRef
    clipNumber: URIRef
    closes: URIRef
    coach: URIRef
    codeRepository: URIRef
    codeSampleType: URIRef
    colleague: URIRef
    colleagues: URIRef
    collection: URIRef
    color: URIRef
    comment: URIRef
    commentCount: URIRef
    commentText: URIRef
    commentTime: URIRef
    competitor: URIRef
    composer: URIRef
    confirmationNumber: URIRef
    contactOption: URIRef
    contactPoint: URIRef
    contactPoints: URIRef
    contactType: URIRef
    containedIn: URIRef
    containedInPlace: URIRef
    containsPlace: URIRef
    containsSeason: URIRef
    contentLocation: URIRef
    contentRating: URIRef
    contentSize: URIRef
    contentType: URIRef
    contentUrl: URIRef
    contributor: URIRef
    cookTime: URIRef
    cookingMethod: URIRef
    copyrightHolder: URIRef
    copyrightYear: URIRef
    countriesNotSupported: URIRef
    countriesSupported: URIRef
    countryOfOrigin: URIRef
    course: URIRef
    courseCode: URIRef
    courseMode: URIRef
    coursePrerequisites: URIRef
    coverageEndTime: URIRef
    coverageStartTime: URIRef
    creator: URIRef
    creditedTo: URIRef
    cssSelector: URIRef
    currenciesAccepted: URIRef
    currency: URIRef
    customer: URIRef
    dataFeedElement: URIRef
    dataset: URIRef
    datasetTimeInterval: URIRef
    dateCreated: URIRef
    dateDeleted: URIRef
    dateIssued: URIRef
    dateModified: URIRef
    datePosted: URIRef
    datePublished: URIRef
    dateRead: URIRef
    dateReceived: URIRef
    dateSent: URIRef
    dateVehicleFirstRegistered: URIRef
    dateline: URIRef
    dayOfWeek: URIRef
    deathDate: URIRef
    deathPlace: URIRef
    defaultValue: URIRef
    deliveryAddress: URIRef
    deliveryLeadTime: URIRef
    deliveryMethod: URIRef
    deliveryStatus: URIRef
    department: URIRef
    departureAirport: URIRef
    departureBusStop: URIRef
    departureGate: URIRef
    departurePlatform: URIRef
    departureStation: URIRef
    departureTerminal: URIRef
    departureTime: URIRef
    dependencies: URIRef
    depth: URIRef
    description: URIRef
    device: URIRef
    director: URIRef
    directors: URIRef
    disambiguatingDescription: URIRef
    discount: URIRef
    discountCode: URIRef
    discountCurrency: URIRef
    discusses: URIRef
    discussionUrl: URIRef
    dissolutionDate: URIRef
    distance: URIRef
    distribution: URIRef
    doorTime: URIRef
    downloadUrl: URIRef
    downvoteCount: URIRef
    driveWheelConfiguration: URIRef
    dropoffLocation: URIRef
    dropoffTime: URIRef
    duns: URIRef
    duration: URIRef
    durationOfWarranty: URIRef
    duringMedia: URIRef
    editor: URIRef
    educationalAlignment: URIRef
    educationalCredentialAwarded: URIRef
    educationalFramework: URIRef
    educationalRole: URIRef
    educationalUse: URIRef
    elevation: URIRef
    eligibleCustomerType: URIRef
    eligibleDuration: URIRef
    eligibleQuantity: URIRef
    eligibleRegion: URIRef
    eligibleTransactionVolume: URIRef
    email: URIRef
    embedUrl: URIRef
    employee: URIRef
    employees: URIRef
    employmentType: URIRef
    encodesCreativeWork: URIRef
    encoding: URIRef
    encodingFormat: URIRef
    encodingType: URIRef
    encodings: URIRef
    endDate: URIRef
    endTime: URIRef
    endorsee: URIRef
    entertainmentBusiness: URIRef
    episode: URIRef
    episodeNumber: URIRef
    episodes: URIRef
    equal: URIRef
    error: URIRef
    estimatedCost: URIRef
    estimatedFlightDuration: URIRef
    estimatedSalary: URIRef
    event: URIRef
    eventStatus: URIRef
    events: URIRef
    exampleOfWork: URIRef
    executableLibraryName: URIRef
    exerciseCourse: URIRef
    exifData: URIRef
    expectedArrivalFrom: URIRef
    expectedArrivalUntil: URIRef
    expectsAcceptanceOf: URIRef
    experienceRequirements: URIRef
    expires: URIRef
    familyName: URIRef
    fatContent: URIRef
    faxNumber: URIRef
    featureList: URIRef
    feesAndCommissionsSpecification: URIRef
    fiberContent: URIRef
    fileFormat: URIRef
    fileSize: URIRef
    firstPerformance: URIRef
    flightDistance: URIRef
    flightNumber: URIRef
    floorSize: URIRef
    followee: URIRef
    follows: URIRef
    foodEstablishment: URIRef
    foodEvent: URIRef
    founder: URIRef
    founders: URIRef
    foundingDate: URIRef
    foundingLocation: URIRef
    free: URIRef
    fromLocation: URIRef
    fuelConsumption: URIRef
    fuelEfficiency: URIRef
    fuelType: URIRef
    funder: URIRef
    game: URIRef
    gameItem: URIRef
    gameLocation: URIRef
    gamePlatform: URIRef
    gameServer: URIRef
    gameTip: URIRef
    genre: URIRef
    geo: URIRef
    geoContains: URIRef
    geoCoveredBy: URIRef
    geoCovers: URIRef
    geoCrosses: URIRef
    geoDisjoint: URIRef
    geoEquals: URIRef
    geoIntersects: URIRef
    geoMidpoint: URIRef
    geoOverlaps: URIRef
    geoRadius: URIRef
    geoTouches: URIRef
    geoWithin: URIRef
    geographicArea: URIRef
    givenName: URIRef
    globalLocationNumber: URIRef
    grantee: URIRef
    greater: URIRef
    greaterOrEqual: URIRef
    gtin12: URIRef
    gtin13: URIRef
    gtin14: URIRef
    gtin8: URIRef
    hasBroadcastChannel: URIRef
    hasCourseInstance: URIRef
    hasDeliveryMethod: URIRef
    hasDigitalDocumentPermission: URIRef
    hasMap: URIRef
    hasMenu: URIRef
    hasMenuItem: URIRef
    hasMenuSection: URIRef
    hasOccupation: URIRef
    hasOfferCatalog: URIRef
    hasPOS: URIRef
    hasPart: URIRef
    headline: URIRef
    height: URIRef
    highPrice: URIRef
    hiringOrganization: URIRef
    homeLocation: URIRef
    homeTeam: URIRef
    honorificPrefix: URIRef
    honorificSuffix: URIRef
    hostingOrganization: URIRef
    hoursAvailable: URIRef
    httpMethod: URIRef
    iataCode: URIRef
    icaoCode: URIRef
    identifier: URIRef
    illustrator: URIRef
    image: URIRef
    inAlbum: URIRef
    inBroadcastLineup: URIRef
    inLanguage: URIRef
    inPlaylist: URIRef
    incentiveCompensation: URIRef
    incentives: URIRef
    includedComposition: URIRef
    includedDataCatalog: URIRef
    includedInDataCatalog: URIRef
    includesObject: URIRef
    industry: URIRef
    ingredients: URIRef
    installUrl: URIRef
    instructor: URIRef
    instrument: URIRef
    interactionCount: URIRef
    interactionService: URIRef
    interactionStatistic: URIRef
    interactionType: URIRef
    interactivityType: URIRef
    interestRate: URIRef
    inventoryLevel: URIRef
    isAccessibleForFree: URIRef
    isAccessoryOrSparePartFor: URIRef
    isBasedOn: URIRef
    isBasedOnUrl: URIRef
    isConsumableFor: URIRef
    isFamilyFriendly: URIRef
    isGift: URIRef
    isLiveBroadcast: URIRef
    isPartOf: URIRef
    isRelatedTo: URIRef
    isSimilarTo: URIRef
    isVariantOf: URIRef
    isbn: URIRef
    isicV4: URIRef
    isrcCode: URIRef
    issn: URIRef
    issueNumber: URIRef
    issuedBy: URIRef
    issuedThrough: URIRef
    iswcCode: URIRef
    item: URIRef
    itemCondition: URIRef
    itemListElement: URIRef
    itemListOrder: URIRef
    itemOffered: URIRef
    itemReviewed: URIRef
    itemShipped: URIRef
    jobBenefits: URIRef
    jobLocation: URIRef
    keywords: URIRef
    knownVehicleDamages: URIRef
    knows: URIRef
    landlord: URIRef
    language: URIRef
    lastReviewed: URIRef
    latitude: URIRef
    learningResourceType: URIRef
    legalName: URIRef
    leiCode: URIRef
    lender: URIRef
    lesser: URIRef
    lesserOrEqual: URIRef
    license: URIRef
    line: URIRef
    liveBlogUpdate: URIRef
    loanTerm: URIRef
    location: URIRef
    locationCreated: URIRef
    lodgingUnitDescription: URIRef
    lodgingUnitType: URIRef
    logo: URIRef
    longitude: URIRef
    loser: URIRef
    lowPrice: URIRef
    lyricist: URIRef
    lyrics: URIRef
    mainContentOfPage: URIRef
    mainEntity: URIRef
    mainEntityOfPage: URIRef
    makesOffer: URIRef
    manufacturer: URIRef
    map: URIRef
    mapType: URIRef
    maps: URIRef
    material: URIRef
    maxPrice: URIRef
    maxValue: URIRef
    maximumAttendeeCapacity: URIRef
    mealService: URIRef
    median: URIRef
    member: URIRef
    memberOf: URIRef
    members: URIRef
    membershipNumber: URIRef
    memoryRequirements: URIRef
    mentions: URIRef
    menu: URIRef
    menuAddOn: URIRef
    merchant: URIRef
    messageAttachment: URIRef
    mileageFromOdometer: URIRef
    minPrice: URIRef
    minValue: URIRef
    minimumPaymentDue: URIRef
    model: URIRef
    modifiedTime: URIRef
    mpn: URIRef
    multipleValues: URIRef
    musicArrangement: URIRef
    musicBy: URIRef
    musicCompositionForm: URIRef
    musicGroupMember: URIRef
    musicReleaseFormat: URIRef
    musicalKey: URIRef
    naics: URIRef
    name: URIRef
    namedPosition: URIRef
    nationality: URIRef
    netWorth: URIRef
    nextItem: URIRef
    nonEqual: URIRef
    numAdults: URIRef
    numChildren: URIRef
    numTracks: URIRef
    numberOfAirbags: URIRef
    numberOfAxles: URIRef
    numberOfBeds: URIRef
    numberOfDoors: URIRef
    numberOfEmployees: URIRef
    numberOfEpisodes: URIRef
    numberOfForwardGears: URIRef
    numberOfItems: URIRef
    numberOfPages: URIRef
    numberOfPlayers: URIRef
    numberOfPreviousOwners: URIRef
    numberOfRooms: URIRef
    numberOfSeasons: URIRef
    numberedPosition: URIRef
    nutrition: URIRef
    object: URIRef
    occupancy: URIRef
    occupationLocation: URIRef
    offerCount: URIRef
    offeredBy: URIRef
    offers: URIRef
    openingHours: URIRef
    openingHoursSpecification: URIRef
    opens: URIRef
    operatingSystem: URIRef
    opponent: URIRef
    option: URIRef
    orderDate: URIRef
    orderDelivery: URIRef
    orderItemNumber: URIRef
    orderItemStatus: URIRef
    orderNumber: URIRef
    orderQuantity: URIRef
    orderStatus: URIRef
    orderedItem: URIRef
    organizer: URIRef
    originAddress: URIRef
    ownedFrom: URIRef
    ownedThrough: URIRef
    owns: URIRef
    pageEnd: URIRef
    pageStart: URIRef
    pagination: URIRef
    parent: URIRef
    parentItem: URIRef
    parentOrganization: URIRef
    parentService: URIRef
    parents: URIRef
    partOfEpisode: URIRef
    partOfInvoice: URIRef
    partOfOrder: URIRef
    partOfSeason: URIRef
    partOfSeries: URIRef
    partOfTVSeries: URIRef
    participant: URIRef
    partySize: URIRef
    passengerPriorityStatus: URIRef
    passengerSequenceNumber: URIRef
    paymentAccepted: URIRef
    paymentDue: URIRef
    paymentDueDate: URIRef
    paymentMethod: URIRef
    paymentMethodId: URIRef
    paymentStatus: URIRef
    paymentUrl: URIRef
    percentile10: URIRef
    percentile25: URIRef
    percentile75: URIRef
    percentile90: URIRef
    performTime: URIRef
    performer: URIRef
    performerIn: URIRef
    performers: URIRef
    permissionType: URIRef
    permissions: URIRef
    permitAudience: URIRef
    permittedUsage: URIRef
    petsAllowed: URIRef
    photo: URIRef
    photos: URIRef
    pickupLocation: URIRef
    pickupTime: URIRef
    playMode: URIRef
    playerType: URIRef
    playersOnline: URIRef
    polygon: URIRef
    position: URIRef
    postOfficeBoxNumber: URIRef
    postalCode: URIRef
    potentialAction: URIRef
    predecessorOf: URIRef
    prepTime: URIRef
    previousItem: URIRef
    previousStartDate: URIRef
    price: URIRef
    priceComponent: URIRef
    priceCurrency: URIRef
    priceRange: URIRef
    priceSpecification: URIRef
    priceType: URIRef
    priceValidUntil: URIRef
    primaryImageOfPage: URIRef
    printColumn: URIRef
    printEdition: URIRef
    printPage: URIRef
    printSection: URIRef
    processingTime: URIRef
    processorRequirements: URIRef
    producer: URIRef
    produces: URIRef
    productID: URIRef
    productSupported: URIRef
    productionCompany: URIRef
    productionDate: URIRef
    proficiencyLevel: URIRef
    programMembershipUsed: URIRef
    programName: URIRef
    programmingLanguage: URIRef
    programmingModel: URIRef
    propertyID: URIRef
    proteinContent: URIRef
    provider: URIRef
    providerMobility: URIRef
    providesBroadcastService: URIRef
    providesService: URIRef
    publicAccess: URIRef
    publication: URIRef
    publishedOn: URIRef
    publisher: URIRef
    publishingPrinciples: URIRef
    purchaseDate: URIRef
    query: URIRef
    quest: URIRef
    question: URIRef
    ratingCount: URIRef
    ratingValue: URIRef
    readonlyValue: URIRef
    realEstateAgent: URIRef
    recipe: URIRef
    recipeCategory: URIRef
    recipeCuisine: URIRef
    recipeIngredient: URIRef
    recipeInstructions: URIRef
    recipeYield: URIRef
    recipient: URIRef
    recordLabel: URIRef
    recordedAs: URIRef
    recordedAt: URIRef
    recordedIn: URIRef
    recordingOf: URIRef
    referenceQuantity: URIRef
    referencesOrder: URIRef
    regionsAllowed: URIRef
    relatedLink: URIRef
    relatedTo: URIRef
    releaseDate: URIRef
    releaseNotes: URIRef
    releaseOf: URIRef
    releasedEvent: URIRef
    relevantOccupation: URIRef
    remainingAttendeeCapacity: URIRef
    replacee: URIRef
    replacer: URIRef
    replyToUrl: URIRef
    reportNumber: URIRef
    representativeOfPage: URIRef
    requiredCollateral: URIRef
    requiredGender: URIRef
    requiredMaxAge: URIRef
    requiredMinAge: URIRef
    requiredQuantity: URIRef
    requirements: URIRef
    requiresSubscription: URIRef
    reservationFor: URIRef
    reservationId: URIRef
    reservationStatus: URIRef
    reservedTicket: URIRef
    responsibilities: URIRef
    result: URIRef
    resultComment: URIRef
    resultReview: URIRef
    review: URIRef
    reviewAspect: URIRef
    reviewBody: URIRef
    reviewCount: URIRef
    reviewRating: URIRef
    reviewedBy: URIRef
    reviews: URIRef
    roleName: URIRef
    rsvpResponse: URIRef
    runtime: URIRef
    runtimePlatform: URIRef
    salaryCurrency: URIRef
    sameAs: URIRef
    sampleType: URIRef
    saturatedFatContent: URIRef
    scheduledPaymentDate: URIRef
    scheduledTime: URIRef
    schemaVersion: URIRef
    screenCount: URIRef
    screenshot: URIRef
    season: URIRef
    seasonNumber: URIRef
    seasons: URIRef
    seatNumber: URIRef
    seatRow: URIRef
    seatSection: URIRef
    seatingType: URIRef
    securityScreening: URIRef
    seeks: URIRef
    seller: URIRef
    sender: URIRef
    serialNumber: URIRef
    serverStatus: URIRef
    servesCuisine: URIRef
    serviceArea: URIRef
    serviceAudience: URIRef
    serviceLocation: URIRef
    serviceOperator: URIRef
    serviceOutput: URIRef
    servicePhone: URIRef
    servicePostalAddress: URIRef
    serviceSmsNumber: URIRef
    serviceType: URIRef
    serviceUrl: URIRef
    servingSize: URIRef
    sharedContent: URIRef
    sibling: URIRef
    siblings: URIRef
    significantLink: URIRef
    significantLinks: URIRef
    skills: URIRef
    sku: URIRef
    slogan: URIRef
    smokingAllowed: URIRef
    sodiumContent: URIRef
    softwareAddOn: URIRef
    softwareHelp: URIRef
    softwareRequirements: URIRef
    softwareVersion: URIRef
    sourceOrganization: URIRef
    spatial: URIRef
    spatialCoverage: URIRef
    speakable: URIRef
    specialCommitments: URIRef
    specialOpeningHoursSpecification: URIRef
    specialty: URIRef
    sponsor: URIRef
    sportsActivityLocation: URIRef
    sportsEvent: URIRef
    sportsTeam: URIRef
    spouse: URIRef
    starRating: URIRef
    startDate: URIRef
    startTime: URIRef
    steeringPosition: URIRef
    step: URIRef
    stepValue: URIRef
    steps: URIRef
    storageRequirements: URIRef
    streetAddress: URIRef
    subEvent: URIRef
    subEvents: URIRef
    subOrganization: URIRef
    subReservation: URIRef
    subjectOf: URIRef
    successorOf: URIRef
    sugarContent: URIRef
    suggestedAnswer: URIRef
    suggestedGender: URIRef
    suggestedMaxAge: URIRef
    suggestedMinAge: URIRef
    suitableForDiet: URIRef
    superEvent: URIRef
    supply: URIRef
    supportingData: URIRef
    surface: URIRef
    target: URIRef
    targetCollection: URIRef
    targetDescription: URIRef
    targetName: URIRef
    targetPlatform: URIRef
    targetProduct: URIRef
    targetUrl: URIRef
    taxID: URIRef
    telephone: URIRef
    temporal: URIRef
    temporalCoverage: URIRef
    text: URIRef
    thumbnail: URIRef
    thumbnailUrl: URIRef
    tickerSymbol: URIRef
    ticketNumber: URIRef
    ticketToken: URIRef
    ticketedSeat: URIRef
    timeRequired: URIRef
    title: URIRef
    toLocation: URIRef
    toRecipient: URIRef
    tool: URIRef
    totalPaymentDue: URIRef
    totalPrice: URIRef
    totalTime: URIRef
    touristType: URIRef
    track: URIRef
    trackingNumber: URIRef
    trackingUrl: URIRef
    tracks: URIRef
    trailer: URIRef
    trainName: URIRef
    trainNumber: URIRef
    transFatContent: URIRef
    transcript: URIRef
    translator: URIRef
    typeOfBed: URIRef
    typeOfGood: URIRef
    typicalAgeRange: URIRef
    underName: URIRef
    unitCode: URIRef
    unitText: URIRef
    unsaturatedFatContent: URIRef
    uploadDate: URIRef
    upvoteCount: URIRef
    url: URIRef
    urlTemplate: URIRef
    userInteractionCount: URIRef
    validFor: URIRef
    validFrom: URIRef
    validIn: URIRef
    validThrough: URIRef
    validUntil: URIRef
    value: URIRef
    valueAddedTaxIncluded: URIRef
    valueMaxLength: URIRef
    valueMinLength: URIRef
    valueName: URIRef
    valuePattern: URIRef
    valueReference: URIRef
    valueRequired: URIRef
    vatID: URIRef
    vehicleConfiguration: URIRef
    vehicleEngine: URIRef
    vehicleIdentificationNumber: URIRef
    vehicleInteriorColor: URIRef
    vehicleInteriorType: URIRef
    vehicleModelDate: URIRef
    vehicleSeatingCapacity: URIRef
    vehicleTransmission: URIRef
    vendor: URIRef
    version: URIRef
    video: URIRef
    videoFormat: URIRef
    videoFrameSize: URIRef
    videoQuality: URIRef
    volumeNumber: URIRef
    warranty: URIRef
    warrantyPromise: URIRef
    warrantyScope: URIRef
    webCheckinTime: URIRef
    weight: URIRef
    width: URIRef
    winner: URIRef
    wordCount: URIRef
    workExample: URIRef
    workFeatured: URIRef
    workHours: URIRef
    workLocation: URIRef
    workPerformed: URIRef
    workPresented: URIRef
    worksFor: URIRef
    worstRating: URIRef
    xpath: URIRef
    yearlyRevenue: URIRef
    yearsInOperation: URIRef
    AMRadioChannel: URIRef
    APIReference: URIRef
    AboutPage: URIRef
    AcceptAction: URIRef
    Accommodation: URIRef
    AccountingService: URIRef
    AchieveAction: URIRef
    Action: URIRef
    ActionAccessSpecification: URIRef
    ActionStatusType: URIRef
    ActivateAction: URIRef
    AddAction: URIRef
    AdministrativeArea: URIRef
    AdultEntertainment: URIRef
    AggregateOffer: URIRef
    AggregateRating: URIRef
    AgreeAction: URIRef
    Airline: URIRef
    Airport: URIRef
    AlignmentObject: URIRef
    AllocateAction: URIRef
    AmusementPark: URIRef
    AnimalShelter: URIRef
    Answer: URIRef
    Apartment: URIRef
    ApartmentComplex: URIRef
    AppendAction: URIRef
    ApplyAction: URIRef
    Aquarium: URIRef
    ArriveAction: URIRef
    ArtGallery: URIRef
    Article: URIRef
    AskAction: URIRef
    AssessAction: URIRef
    AssignAction: URIRef
    Attorney: URIRef
    Audience: URIRef
    AudioObject: URIRef
    AuthorizeAction: URIRef
    AutoBodyShop: URIRef
    AutoDealer: URIRef
    AutoPartsStore: URIRef
    AutoRental: URIRef
    AutoRepair: URIRef
    AutoWash: URIRef
    AutomatedTeller: URIRef
    AutomotiveBusiness: URIRef
    Bakery: URIRef
    BankAccount: URIRef
    BankOrCreditUnion: URIRef
    BarOrPub: URIRef
    Barcode: URIRef
    Beach: URIRef
    BeautySalon: URIRef
    BedAndBreakfast: URIRef
    BedDetails: URIRef
    BedType: URIRef
    BefriendAction: URIRef
    BikeStore: URIRef
    Blog: URIRef
    BlogPosting: URIRef
    BoardingPolicyType: URIRef
    BodyOfWater: URIRef
    Book: URIRef
    BookFormatType: URIRef
    BookSeries: URIRef
    BookStore: URIRef
    BookmarkAction: URIRef
    Boolean: URIRef
    BorrowAction: URIRef
    BowlingAlley: URIRef
    Brand: URIRef
    BreadcrumbList: URIRef
    Brewery: URIRef
    Bridge: URIRef
    BroadcastChannel: URIRef
    BroadcastEvent: URIRef
    BroadcastFrequencySpecification: URIRef
    BroadcastService: URIRef
    BuddhistTemple: URIRef
    BusReservation: URIRef
    BusStation: URIRef
    BusStop: URIRef
    BusTrip: URIRef
    BusinessAudience: URIRef
    BusinessEntityType: URIRef
    BusinessEvent: URIRef
    BusinessFunction: URIRef
    BuyAction: URIRef
    CableOrSatelliteService: URIRef
    CafeOrCoffeeShop: URIRef
    Campground: URIRef
    CampingPitch: URIRef
    Canal: URIRef
    CancelAction: URIRef
    Car: URIRef
    Casino: URIRef
    CatholicChurch: URIRef
    Cemetery: URIRef
    CheckAction: URIRef
    CheckInAction: URIRef
    CheckOutAction: URIRef
    CheckoutPage: URIRef
    ChildCare: URIRef
    ChildrensEvent: URIRef
    ChooseAction: URIRef
    Church: URIRef
    City: URIRef
    CityHall: URIRef
    CivicStructure: URIRef
    ClaimReview: URIRef
    Clip: URIRef
    ClothingStore: URIRef
    Code: URIRef
    CollectionPage: URIRef
    CollegeOrUniversity: URIRef
    ComedyClub: URIRef
    ComedyEvent: URIRef
    Comment: URIRef
    CommentAction: URIRef
    CommunicateAction: URIRef
    CompoundPriceSpecification: URIRef
    ComputerLanguage: URIRef
    ComputerStore: URIRef
    ConfirmAction: URIRef
    ConsumeAction: URIRef
    ContactPage: URIRef
    ContactPoint: URIRef
    ContactPointOption: URIRef
    Continent: URIRef
    ControlAction: URIRef
    ConvenienceStore: URIRef
    Conversation: URIRef
    CookAction: URIRef
    Corporation: URIRef
    Country: URIRef
    Course: URIRef
    CourseInstance: URIRef
    Courthouse: URIRef
    CreateAction: URIRef
    CreativeWork: URIRef
    CreativeWorkSeason: URIRef
    CreativeWorkSeries: URIRef
    CreditCard: URIRef
    Crematorium: URIRef
    CurrencyConversionService: URIRef
    DanceEvent: URIRef
    DanceGroup: URIRef
    DataCatalog: URIRef
    DataDownload: URIRef
    DataFeed: URIRef
    DataFeedItem: URIRef
    DataType: URIRef
    Dataset: URIRef
    Date: URIRef
    DateTime: URIRef
    DatedMoneySpecification: URIRef
    DayOfWeek: URIRef
    DaySpa: URIRef
    DeactivateAction: URIRef
    DefenceEstablishment: URIRef
    DeleteAction: URIRef
    DeliveryChargeSpecification: URIRef
    DeliveryEvent: URIRef
    DeliveryMethod: URIRef
    Demand: URIRef
    Dentist: URIRef
    DepartAction: URIRef
    DepartmentStore: URIRef
    DepositAccount: URIRef
    DigitalDocument: URIRef
    DigitalDocumentPermission: URIRef
    DigitalDocumentPermissionType: URIRef
    DisagreeAction: URIRef
    DiscoverAction: URIRef
    DiscussionForumPosting: URIRef
    DislikeAction: URIRef
    Distance: URIRef
    Distillery: URIRef
    DonateAction: URIRef
    DownloadAction: URIRef
    DrawAction: URIRef
    DrinkAction: URIRef
    DriveWheelConfigurationValue: URIRef
    DryCleaningOrLaundry: URIRef
    Duration: URIRef
    EatAction: URIRef
    EducationEvent: URIRef
    EducationalAudience: URIRef
    EducationalOrganization: URIRef
    Electrician: URIRef
    ElectronicsStore: URIRef
    ElementarySchool: URIRef
    EmailMessage: URIRef
    Embassy: URIRef
    EmergencyService: URIRef
    EmployeeRole: URIRef
    EmployerAggregateRating: URIRef
    EmploymentAgency: URIRef
    EndorseAction: URIRef
    EndorsementRating: URIRef
    Energy: URIRef
    EngineSpecification: URIRef
    EntertainmentBusiness: URIRef
    EntryPoint: URIRef
    Enumeration: URIRef
    Episode: URIRef
    Event: URIRef
    EventReservation: URIRef
    EventStatusType: URIRef
    EventVenue: URIRef
    ExerciseAction: URIRef
    ExerciseGym: URIRef
    ExhibitionEvent: URIRef
    FAQPage: URIRef
    FMRadioChannel: URIRef
    FastFoodRestaurant: URIRef
    Festival: URIRef
    FilmAction: URIRef
    FinancialProduct: URIRef
    FinancialService: URIRef
    FindAction: URIRef
    FireStation: URIRef
    Flight: URIRef
    FlightReservation: URIRef
    Float: URIRef
    Florist: URIRef
    FollowAction: URIRef
    FoodEstablishment: URIRef
    FoodEstablishmentReservation: URIRef
    FoodEvent: URIRef
    FoodService: URIRef
    FurnitureStore: URIRef
    Game: URIRef
    GamePlayMode: URIRef
    GameServer: URIRef
    GameServerStatus: URIRef
    GardenStore: URIRef
    GasStation: URIRef
    GatedResidenceCommunity: URIRef
    GenderType: URIRef
    GeneralContractor: URIRef
    GeoCircle: URIRef
    GeoCoordinates: URIRef
    GeoShape: URIRef
    GiveAction: URIRef
    GolfCourse: URIRef
    GovernmentBuilding: URIRef
    GovernmentOffice: URIRef
    GovernmentOrganization: URIRef
    GovernmentPermit: URIRef
    GovernmentService: URIRef
    GroceryStore: URIRef
    HVACBusiness: URIRef
    HairSalon: URIRef
    HardwareStore: URIRef
    HealthAndBeautyBusiness: URIRef
    HealthClub: URIRef
    HighSchool: URIRef
    HinduTemple: URIRef
    HobbyShop: URIRef
    HomeAndConstructionBusiness: URIRef
    HomeGoodsStore: URIRef
    Hospital: URIRef
    Hostel: URIRef
    Hotel: URIRef
    HotelRoom: URIRef
    House: URIRef
    HousePainter: URIRef
    HowTo: URIRef
    HowToDirection: URIRef
    HowToItem: URIRef
    HowToSection: URIRef
    HowToStep: URIRef
    HowToSupply: URIRef
    HowToTip: URIRef
    HowToTool: URIRef
    IceCreamShop: URIRef
    IgnoreAction: URIRef
    ImageGallery: URIRef
    ImageObject: URIRef
    IndividualProduct: URIRef
    InformAction: URIRef
    InsertAction: URIRef
    InstallAction: URIRef
    InsuranceAgency: URIRef
    Intangible: URIRef
    Integer: URIRef
    InteractAction: URIRef
    InteractionCounter: URIRef
    InternetCafe: URIRef
    InvestmentOrDeposit: URIRef
    InviteAction: URIRef
    Invoice: URIRef
    ItemAvailability: URIRef
    ItemList: URIRef
    ItemListOrderType: URIRef
    ItemPage: URIRef
    JewelryStore: URIRef
    JobPosting: URIRef
    JoinAction: URIRef
    LakeBodyOfWater: URIRef
    Landform: URIRef
    LandmarksOrHistoricalBuildings: URIRef
    Language: URIRef
    LeaveAction: URIRef
    LegalService: URIRef
    LegislativeBuilding: URIRef
    LendAction: URIRef
    Library: URIRef
    LikeAction: URIRef
    LiquorStore: URIRef
    ListItem: URIRef
    ListenAction: URIRef
    LiteraryEvent: URIRef
    LiveBlogPosting: URIRef
    LoanOrCredit: URIRef
    LocalBusiness: URIRef
    LocationFeatureSpecification: URIRef
    LockerDelivery: URIRef
    Locksmith: URIRef
    LodgingBusiness: URIRef
    LodgingReservation: URIRef
    LoseAction: URIRef
    Map: URIRef
    MapCategoryType: URIRef
    MarryAction: URIRef
    Mass: URIRef
    MediaGallery: URIRef
    MediaObject: URIRef
    MediaSubscription: URIRef
    MedicalOrganization: URIRef
    MeetingRoom: URIRef
    MensClothingStore: URIRef
    Menu: URIRef
    MenuItem: URIRef
    MenuSection: URIRef
    Message: URIRef
    MiddleSchool: URIRef
    MobileApplication: URIRef
    MobilePhoneStore: URIRef
    MonetaryAmount: URIRef
    MonetaryAmountDistribution: URIRef
    Mosque: URIRef
    Motel: URIRef
    MotorcycleDealer: URIRef
    MotorcycleRepair: URIRef
    Mountain: URIRef
    MoveAction: URIRef
    Movie: URIRef
    MovieClip: URIRef
    MovieRentalStore: URIRef
    MovieSeries: URIRef
    MovieTheater: URIRef
    MovingCompany: URIRef
    Museum: URIRef
    MusicAlbum: URIRef
    MusicAlbumProductionType: URIRef
    MusicAlbumReleaseType: URIRef
    MusicComposition: URIRef
    MusicEvent: URIRef
    MusicGroup: URIRef
    MusicPlaylist: URIRef
    MusicRecording: URIRef
    MusicRelease: URIRef
    MusicReleaseFormatType: URIRef
    MusicStore: URIRef
    MusicVenue: URIRef
    MusicVideoObject: URIRef
    NGO: URIRef
    NailSalon: URIRef
    NewsArticle: URIRef
    NightClub: URIRef
    Notary: URIRef
    NoteDigitalDocument: URIRef
    Number: URIRef
    NutritionInformation: URIRef
    Occupation: URIRef
    OceanBodyOfWater: URIRef
    Offer: URIRef
    OfferCatalog: URIRef
    OfferItemCondition: URIRef
    OfficeEquipmentStore: URIRef
    OnDemandEvent: URIRef
    OpeningHoursSpecification: URIRef
    Order: URIRef
    OrderAction: URIRef
    OrderItem: URIRef
    OrderStatus: URIRef
    Organization: URIRef
    OrganizationRole: URIRef
    OrganizeAction: URIRef
    OutletStore: URIRef
    OwnershipInfo: URIRef
    PaintAction: URIRef
    Painting: URIRef
    ParcelDelivery: URIRef
    ParcelService: URIRef
    ParentAudience: URIRef
    Park: URIRef
    ParkingFacility: URIRef
    PawnShop: URIRef
    PayAction: URIRef
    PaymentCard: URIRef
    PaymentChargeSpecification: URIRef
    PaymentMethod: URIRef
    PaymentService: URIRef
    PaymentStatusType: URIRef
    PeopleAudience: URIRef
    PerformAction: URIRef
    PerformanceRole: URIRef
    PerformingArtsTheater: URIRef
    PerformingGroup: URIRef
    Periodical: URIRef
    Permit: URIRef
    Person: URIRef
    PetStore: URIRef
    Pharmacy: URIRef
    Photograph: URIRef
    PhotographAction: URIRef
    Physician: URIRef
    Place: URIRef
    PlaceOfWorship: URIRef
    PlanAction: URIRef
    PlayAction: URIRef
    Playground: URIRef
    Plumber: URIRef
    PoliceStation: URIRef
    Pond: URIRef
    PostOffice: URIRef
    PostalAddress: URIRef
    PreOrderAction: URIRef
    PrependAction: URIRef
    Preschool: URIRef
    PresentationDigitalDocument: URIRef
    PriceSpecification: URIRef
    Product: URIRef
    ProductModel: URIRef
    ProfessionalService: URIRef
    ProfilePage: URIRef
    ProgramMembership: URIRef
    PropertyValue: URIRef
    PropertyValueSpecification: URIRef
    PublicSwimmingPool: URIRef
    PublicationEvent: URIRef
    PublicationIssue: URIRef
    PublicationVolume: URIRef
    QAPage: URIRef
    QualitativeValue: URIRef
    QuantitativeValue: URIRef
    QuantitativeValueDistribution: URIRef
    Quantity: URIRef
    Question: URIRef
    QuoteAction: URIRef
    RVPark: URIRef
    RadioChannel: URIRef
    RadioClip: URIRef
    RadioEpisode: URIRef
    RadioSeason: URIRef
    RadioSeries: URIRef
    RadioStation: URIRef
    Rating: URIRef
    ReactAction: URIRef
    ReadAction: URIRef
    RealEstateAgent: URIRef
    ReceiveAction: URIRef
    Recipe: URIRef
    RecyclingCenter: URIRef
    RegisterAction: URIRef
    RejectAction: URIRef
    RentAction: URIRef
    RentalCarReservation: URIRef
    ReplaceAction: URIRef
    ReplyAction: URIRef
    Report: URIRef
    Reservation: URIRef
    ReservationPackage: URIRef
    ReservationStatusType: URIRef
    ReserveAction: URIRef
    Reservoir: URIRef
    Residence: URIRef
    Resort: URIRef
    Restaurant: URIRef
    RestrictedDiet: URIRef
    ResumeAction: URIRef
    ReturnAction: URIRef
    Review: URIRef
    ReviewAction: URIRef
    RiverBodyOfWater: URIRef
    Role: URIRef
    RoofingContractor: URIRef
    Room: URIRef
    RsvpAction: URIRef
    RsvpResponseType: URIRef
    SaleEvent: URIRef
    ScheduleAction: URIRef
    ScholarlyArticle: URIRef
    School: URIRef
    ScreeningEvent: URIRef
    Sculpture: URIRef
    SeaBodyOfWater: URIRef
    SearchAction: URIRef
    SearchResultsPage: URIRef
    Season: URIRef
    Seat: URIRef
    SelfStorage: URIRef
    SellAction: URIRef
    SendAction: URIRef
    Series: URIRef
    Service: URIRef
    ServiceChannel: URIRef
    ShareAction: URIRef
    ShoeStore: URIRef
    ShoppingCenter: URIRef
    SingleFamilyResidence: URIRef
    SiteNavigationElement: URIRef
    SkiResort: URIRef
    SocialEvent: URIRef
    SocialMediaPosting: URIRef
    SoftwareApplication: URIRef
    SoftwareSourceCode: URIRef
    SomeProducts: URIRef
    SpeakableSpecification: URIRef
    Specialty: URIRef
    SportingGoodsStore: URIRef
    SportsActivityLocation: URIRef
    SportsClub: URIRef
    SportsEvent: URIRef
    SportsOrganization: URIRef
    SportsTeam: URIRef
    SpreadsheetDigitalDocument: URIRef
    StadiumOrArena: URIRef
    State: URIRef
    SteeringPositionValue: URIRef
    Store: URIRef
    StructuredValue: URIRef
    SubscribeAction: URIRef
    SubwayStation: URIRef
    Suite: URIRef
    SuspendAction: URIRef
    Synagogue: URIRef
    TVClip: URIRef
    TVEpisode: URIRef
    TVSeason: URIRef
    TVSeries: URIRef
    Table: URIRef
    TakeAction: URIRef
    TattooParlor: URIRef
    Taxi: URIRef
    TaxiReservation: URIRef
    TaxiService: URIRef
    TaxiStand: URIRef
    TechArticle: URIRef
    TelevisionChannel: URIRef
    TelevisionStation: URIRef
    TennisComplex: URIRef
    Text: URIRef
    TextDigitalDocument: URIRef
    TheaterEvent: URIRef
    TheaterGroup: URIRef
    Thing: URIRef
    Ticket: URIRef
    TieAction: URIRef
    Time: URIRef
    TipAction: URIRef
    TireShop: URIRef
    TouristAttraction: URIRef
    TouristInformationCenter: URIRef
    ToyStore: URIRef
    TrackAction: URIRef
    TradeAction: URIRef
    TrainReservation: URIRef
    TrainStation: URIRef
    TrainTrip: URIRef
    TransferAction: URIRef
    TravelAction: URIRef
    TravelAgency: URIRef
    Trip: URIRef
    TypeAndQuantityNode: URIRef
    URL: URIRef
    UnRegisterAction: URIRef
    UnitPriceSpecification: URIRef
    UpdateAction: URIRef
    UseAction: URIRef
    UserBlocks: URIRef
    UserCheckins: URIRef
    UserComments: URIRef
    UserDownloads: URIRef
    UserInteraction: URIRef
    UserLikes: URIRef
    UserPageVisits: URIRef
    UserPlays: URIRef
    UserPlusOnes: URIRef
    UserTweets: URIRef
    Vehicle: URIRef
    VideoGallery: URIRef
    VideoGame: URIRef
    VideoGameClip: URIRef
    VideoGameSeries: URIRef
    VideoObject: URIRef
    ViewAction: URIRef
    VisualArtsEvent: URIRef
    VisualArtwork: URIRef
    Volcano: URIRef
    VoteAction: URIRef
    WPAdBlock: URIRef
    WPFooter: URIRef
    WPHeader: URIRef
    WPSideBar: URIRef
    WantAction: URIRef
    WarrantyPromise: URIRef
    WarrantyScope: URIRef
    WatchAction: URIRef
    Waterfall: URIRef
    WearAction: URIRef
    WebApplication: URIRef
    WebPage: URIRef
    WebPageElement: URIRef
    WebSite: URIRef
    WholesaleStore: URIRef
    WinAction: URIRef
    Winery: URIRef
    WorkersUnion: URIRef
    WriteAction: URIRef
    Zoo: URIRef
