# Stubs for cachecontrol.caches (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

from .file_cache import FileCache as FileCache

# from .redis_cache import RedisCache as RedisCache

notice = ...  # type: Any
