# Stubs for cachecontrol.filewrapper (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

class CallbackFileWrapper:
    def __init__(self, fp, callback): ...
    def __getattr__(self, name): ...
    def read(self, amt=None): ...
