from typing import Any

class Container:
    graph: Any
    uri: Any
    def __init__(self, graph, uri, seq=..., rtype: str = ...) -> None: ...
    def n3(self): ...
    def __len__(self): ...
    def type_of_conatiner(self): ...
    def index(self, item): ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value) -> None: ...
    def __delitem__(self, key) -> None: ...
    def items(self): ...
    def end(self): ...
    def append(self, item): ...
    def append_multiple(self, other): ...
    def clear(self): ...

class Bag(Container):
    def __init__(self, graph, uri, seq=...) -> None: ...

class Alt(Container):
    def __init__(self, graph, uri, seq=...) -> None: ...
    def anyone(self): ...

class Seq(Container):
    def __init__(self, graph, uri, seq=...) -> None: ...
    def add_at_position(self, pos, item): ...

class NoElementException(Exception):
    message: Any
    def __init__(self, message: str = ...) -> None: ...
