# Stubs for cachecontrol.cache (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class BaseCache:
    def get(self, key): ...
    def set(self, key, value): ...
    def delete(self, key): ...
    def close(self): ...

class DictCache(BaseCache):
    lock = ...  # type: Any
    data = ...  # type: Any
    def __init__(self, init_dict=None): ...
    def get(self, key): ...
    def set(self, key, value): ...
    def delete(self, key): ...
