# Stubs for cachecontrol.wrapper (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

from .adapter import CacheControlAdapter
from .cache import DictCache

def CacheControl(
    sess: Any,
    cache: Optional[Any] = ...,
    cache_etags: bool = ...,
    serializer: Optional[Any] = ...,
    heuristic: Optional[Any] = ...,
): ...
