# Stubs for cachecontrol.serialize (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .compat import HTTPResponse as HTTPResponse
from .compat import pickle as pickle
from .compat import str as str

class Serializer:
    def dumps(self, request, response, body=None): ...
    def loads(self, request, data): ...
    def prepare_response(self, request, cached): ...
