from rdflib.namespace import DefinedNamespace as DefinedNamespace
from rdflib.namespace import Namespace as Namespace
from rdflib.term import URIRef as URIRef

class CSVW(DefinedNamespace):
    aboutUrl: URIRef
    base: URIRef
    column: URIRef
    columnReference: URIRef
    commentPrefix: URIRef
    datatype: URIRef
    decimalChar: URIRef
    default: URIRef
    delimiter: URIRef
    describes: URIRef
    dialect: URIRef
    doubleQuote: URIRef
    encoding: URIRef
    foreignKey: URIRef
    format: URIRef
    groupChar: URIRef
    header: URIRef
    headerRowCount: URIRef
    lang: URIRef
    length: URIRef
    lineTerminators: URIRef
    maxExclusive: URIRef
    maxInclusive: URIRef
    maxLength: URIRef
    minExclusive: URIRef
    minInclusive: URIRef
    minLength: URIRef
    name: URIRef
    note: URIRef
    null: URIRef
    ordered: URIRef
    pattern: URIRef
    primaryKey: URIRef
    propertyUrl: URIRef
    quoteChar: URIRef
    reference: URIRef
    referencedRow: URIRef
    required: URIRef
    resource: URIRef
    row: URIRef
    rowTitle: URIRef
    rownum: URIRef
    schemaReference: URIRef
    scriptFormat: URIRef
    separator: URIRef
    skipBlankRows: URIRef
    skipColumns: URIRef
    skipInitialSpace: URIRef
    skipRows: URIRef
    source: URIRef
    suppressOutput: URIRef
    table: URIRef
    tableDirection: URIRef
    tableSchema: URIRef
    targetFormat: URIRef
    textDirection: URIRef
    title: URIRef
    transformations: URIRef
    trim: URIRef
    url: URIRef
    valueUrl: URIRef
    virtual: URIRef
    Cell: URIRef
    Column: URIRef
    Datatype: URIRef
    Dialect: URIRef
    Direction: URIRef
    ForeignKey: URIRef
    NumericFormat: URIRef
    Row: URIRef
    Schema: URIRef
    Table: URIRef
    TableGroup: URIRef
    TableReference: URIRef
    Transformation: URIRef
    JSON: URIRef
    uriTemplate: URIRef
    auto: URIRef
    inherit: URIRef
    ltr: URIRef
    rtl: URIRef
    csvEncodedTabularData: URIRef
    tabularMetadata: URIRef
